@@ -134,11 +134,15 @@ sub getSiteProtocol($)
     return "";
 }
 
+sub getSite($) {
+    return getSiteProtocol($_[0]).getSiteAddr($_[0]);
+}
+
 sub extractPackage($$)
 {
     my ($Path, $OutDir) = @_;
     
-    if($Path=~/\.(tar\.\w+|tgz|tbz2)\Z/i) {
+    if($Path=~/\.(tar\.\w+|tgz|tbz2|txz)\Z/i) {
         return "tar -xf $Path --directory=$OutDir";
     }
     elsif($Path=~/\.zip\Z/i) {
@@ -154,10 +158,9 @@ sub isHeader($)
     return ($Path=~/\.(h|hh|hp|hxx|hpp|h\+\+|tcc)\Z/i);
 }
 
-sub check_Cmd($)
+sub checkCmd($)
 {
     my $Cmd = $_[0];
-    return 0 if(not $Cmd);
     
     if(-x $Cmd) {
         return 1;
