@@ -1,7 +1,7 @@
 ##################################################################
 # Module for ABI Monitor to compare library versions
 #
-# Copyright (C) 2016 Andrey Ponomarenko's ABI Laboratory
+# Copyright (C) 2017 Andrey Ponomarenko's ABI Laboratory
 #
 # Written by Andrey Ponomarenko
 #
@@ -299,9 +299,16 @@ sub cmpVersions_P($$$)
     return cmpVersions($A, $B);
 }
 
-sub skipVersion($$)
+sub skipVersion(@)
 {
-    my ($V, $Profile) = @_;
+    my $V = shift(@_);
+    my $Profile = shift(@_);
+    
+    my $MinCheck = 1;
+    
+    if(@_) {
+        $MinCheck = shift(@_);
+    }
     
     if(defined $Profile->{"SkipVersions"})
     {
@@ -309,7 +316,7 @@ sub skipVersion($$)
         
         foreach my $E (@Skip)
         {
-            if($E=~/[\*\+\(\|\\]/)
+            if($E=~/[\*\+\[\(\|\\]/)
             { # pattern
                 if($V=~/\A$E\Z/) {
                     return 1;
@@ -320,7 +327,54 @@ sub skipVersion($$)
             }
         }
     }
-    elsif(defined $Profile->{"SkipOdd"})
+    
+    if(defined $Profile->{"KeepMiniMult"})
+    {
+        my @KeepMult = @{$Profile->{"KeepMiniMult"}};
+        
+        if(my $Mini = getVerNum($V, 2))
+        {
+            my $Keep = 0;
+            
+            foreach my $K (@KeepMult)
+            {
+                if($Mini % $K == 0)
+                {
+                    $Keep = 1;
+                    last;
+                }
+            }
+            
+            if(not $Keep) {
+                return 1;
+            }
+        }
+    }
+    
+    if(defined $Profile->{"KeepMicroMult"})
+    {
+        my @KeepMult = @{$Profile->{"KeepMicroMult"}};
+        
+        if(my $Micro = getVerNum($V, 3))
+        {
+            my $Keep = 0;
+            
+            foreach my $K (@KeepMult)
+            {
+                if($Micro % $K == 0)
+                {
+                    $Keep = 1;
+                    last;
+                }
+            }
+            
+            if(not $Keep) {
+                return 1;
+            }
+        }
+    }
+    
+    if(defined $Profile->{"SkipOdd"})
     {
         if($V=~/\A\d+\.(\d+)/)
         {
@@ -331,11 +385,14 @@ sub skipVersion($$)
         }
     }
     
-    if(my $Min = $Profile->{"MinimalVersion"})
+    if($MinCheck)
     {
-        if(cmpVersions_P($V, $Min, $Profile)==-1)
+        if(my $Min = $Profile->{"MinimalVersion"})
         {
-            return 1;
+            if(cmpVersions_P($V, $Min, $Profile)==-1)
+            {
+                return 1;
+            }
         }
     }
     
@@ -435,13 +492,20 @@ sub getVersionType($$)
     
     if(defined $Profile->{"LetterReleases"})
     {
-        if($Version=~/\A[\d\.\-]+[a-z]*\Z/i
+        if($Version=~/\A[\d\.\-]+[a-z]{0,2}\Z/i
         and index($Version, "beta")==-1)
         {
             return "release";
         }
     }
     
+    if(defined $Profile->{"NumericBeta"})
+    {
+        if($Version=~/\A\d+\.\d+\.9\d+(|\.\d+)\Z/i) {
+            return "beta";
+        }
+    }
+    
     if(checkReleasePattern($Version, $Profile)) {
         return "release";
     }
@@ -520,4 +584,19 @@ sub getMajor($$)
     return $V;
 }
 
+sub getVerNum($$)
+{
+    my ($V, $N) = @_;
+    
+    $V=~s/[\-_]/./g;
+    
+    my @P = split(/\./, $V);
+    
+    return $P[$N-1];
+}
+
+sub getVDepth($) {
+    return $_[0]=~tr!\.!!;
+}
+
 return 1;
